@@ -1,5 +1,10 @@
+import sys,os
+sys.path.append(os.path.join(os.path.dirname(__file__),os.pardir,"src"))
 import sida
 
+def test_version():
+    assert sida.__version__ == "0.1.2"
+
 def test_fullname():
     # test full name, run by travis
     assert sida.fullname() == "Sida Liu"
